//
//  PlayerViewController.swift
//  AmpNielsenSample
//
//  Created by Lopez Valenciano, Miguel on 11/27/17.
//  Copyright © 2023 Akamai. All rights reserved.
//

import UIKit
import AVFoundation
import AmpCore
import AmpNielsen

class PlayerViewController: UIViewController, AmpNielsenObserver {
    
    var ampPlayer: AmpPlayer!
    var ampNielsen: AmpNielsenManager!
    
    let url = "http://devimages.apple.com/iphone/samples/bipbop/bipbopall.m3u8"
    
    let imaPreRoll = "https://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpreonly&cmsid=496&vid=short_onecue&correlator="
    
    let imaPreMidPost = "https://pubads.g.doubleclick.net/gampad/ads?sz=640x480&iu=/124319096/external/ad_rule_samples&ciu_szs=300x250&ad_rule=1&impl=s&gdfp_req=1&env=vp&output=vmap&unviewed_position_start=1&cust_params=deployment%3Ddevsite%26sample_ar%3Dpremidpost&cmsid=496&vid=short_onecue&correlator="
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        self.createPlayer()
        
        // Instantiate the IMA Manager after our player is created
    }
    
    func createPlayer() {
        if self.ampPlayer == nil {
            
            self.ampPlayer = AmpPlayer(parentView: self.view)
            self.ampPlayer.setLicense("AwEbB31T8jJuRkWdVPfcQfzyd419ARF2KNT2CJsHGjaqUF4kbJfsc7WbMNuIiSRMRKAXiyDf5zf35Xy3x5ZBEziEO/xh0UlEUMlZ78+C1ttECqNX4BRuMMZlXcOEoryasao4eKbOBD4pesZ2tLtfOHqQ4FRFdF8yhuPD09+S5IJ+A0vEOVZvFIhE/RiKkrnpMn7pby9rwW+A0qqvHrfyKm95RqsSLBKwkk5KSQWxZ4fHCg==")
            
            // Register
            self.ampPlayer.registerObserver(self)
            
            self.setupNielsen()
            
            let times = [2.0, 4.0, 6.0, 8.0]
            _ = CuepointManager(ampPlayer: self.ampPlayer, observer: self, times: times)
            
            self.ampNielsen.registerObserver(self)
            
            self.ampPlayer.play(url: url)
            self.ampPlayer.autoplay = true
        }
    }
    
    func setupNielsen() {
        let appId = "T94C91A1F-C749-4847-ABB6-481365FD3C13"
        
        let appInfo = """
        {"appid": "\(appId)",
        "sfcode": "cert",
        "appname": "Akamai",
        "appversion":"3.0.0",
        "nol_devDebug": "DEBUG"}
        """
        
        self.ampNielsen = AmpNielsenManager(player: self.ampPlayer!, appInfo: appInfo)
        let metaData = """
            {"type": "content",
            "assetName": "myassetName",
            "length": "123",
            "title": "NiceName",
            "program": "myProgram",
            "assetid": "myAssetId",
            "channelName": "myChannel",
            "segB": "segmentB",
            "segC": "segmentC",
            "isfullepisode": "Y",
            "crossId1": "Reference11",
            "crossId2": "Reference22",
            "airdate": "20161013 20:00:00",
            "adloadtype": "2",
            "mediaURL": "http://www.akamai.com/",
            "segA":"segmentA",
            "progen": "CV"
        }
        """
        self.ampNielsen?.set(metaData: metaData)
    }

    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }
    
    override open func viewWillDisappear(_ animated:Bool) {
        if (self.isMovingFromParentViewController) {
            self.ampPlayer.stop()
            self.ampPlayer = nil
            print("Stopped")
        }
        super.viewWillDisappear(animated)
    }
    
    func onReceiveMetaData(_ player: AmpCore.AmpPlayer, metaData: AVMetadataItem) {
        print ("Jairo: An event occurred \(metaData)")
    }
    
    func eventOccurred(_ player: AmpCore.AmpPlayer, appId: String, eventOccurred: [NSObject : AnyObject]) {
        print ("Jairo: An event occurred \(eventOccurred)")
    }
    
    func errorOccurred(_ player: AmpCore.AmpPlayer, appId: String, error: [NSObject : AnyObject]) {
        print ("Jairo: An error occurred \(error)")
    }
}

extension PlayerViewController : PlayerEventObserver {
    
    func onPlaybackStateChanged(_ ampPlayer: AmpPlayer) {
        print("onPlaybackStateChanged")
    }
    
}

